@@ -85,16 +85,21 @@ LaunchDarklyParams: OrgParams = {
         "catamorphic-dr": Profile(
             display_name="Catamorphic DR",
             region="us-east-1",
-            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic-dr",
+            arn="arn:aws:iam::554582317989:role/ops/SSHAdmin-catamorphic_dr",
             ansible_bucket="launchdarkly-sym-ansible-catamorphic-dr",
             aliases=["catamorphic_dr"],
         ),
-        "prod-intuit": Profile(
-            display_name="Intuit: Prod",
+        "intuit-production": Profile(
+            display_name="Intuit: Production",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-production",
             ansible_bucket="launchdarkly-sym-ansible-prod-intuit",
-            aliases=["production-intuit", "intuit_production", "intuit_production_use2"],
+            aliases=[
+                "prod-intuit",
+                "production-intuit",
+                "intuit_production",
+                "intuit_production_use2",
+            ],
         ),
         "intuit-dr": Profile(
             display_name="Intuit: DR",
@@ -103,12 +108,12 @@ LaunchDarklyParams: OrgParams = {
             ansible_bucket="launchdarkly-sym-ansible-intuit-dr",
             aliases=["intuit_dr"],
         ),
-        "staging-intuit": Profile(
+        "intuit-staging": Profile(
             display_name="Intuit: Staging",
             region="us-west-2",
             arn="arn:aws:iam::527291094460:role/ops/SSHAdmin-staging",
             ansible_bucket="launchdarkly-sym-ansible-staging-intuit",
-            aliases=["intuit_staging", "intuit_staging_use2"],
+            aliases=["staging-intuit", "intuit_staging", "intuit_staging_use2"],
         ),
         "production_apac": Profile(
             display_name="Production: APAC",
