@@ -8,8 +8,11 @@ from unittest.mock import MagicMock, patch
 import pytest
 import responses
 from freezegun import freeze_time
+from semver import VersionInfo
 from sym.shared.cli.helpers.updater import SymUpdater
 
+CURRENT_ISH_VERSION = VersionInfo.parse("0.1.41")
+
 
 @pytest.fixture
 def time_travel() -> Iterator:
@@ -39,8 +42,8 @@ def http_mock(pypi_response) -> Iterator:
             )
             rsps.add(
                 responses.GET,
-                "https://pypi.org/pypi/sym-cli/0.0.66/json",
-                json=pypi_response("sym-cli-66"),
+                f"https://pypi.org/pypi/sym-cli/{CURRENT_ISH_VERSION}/json",
+                json=pypi_response("sym-cli-0.1.41"),
             )
         yield rsps
 
